@@ -94,6 +94,15 @@ admin.site.register(models.Document)
 admin.site.register(models.Image)
 admin.site.register(models.PieceOfHtml)
 admin.site.register(models.NewsletterSending)
+admin.site.register(models.FragmentType)
+admin.site.register(models.FragmentFilter)
+
+class FragmentAdmin(BaseAdminClass):
+    pass
+    list_display = ['name', 'position', 'type', 'filter', 'css_class']
+    list_filter = ['type', 'filter', 'css_class']
+
+admin.site.register(models.Fragment, FragmentAdmin)
 
 
 class ArticleCategoryAdmin(admin.ModelAdmin):
@@ -103,7 +112,7 @@ admin.site.register(models.ArticleCategory, ArticleCategoryAdmin)
 
 class NewsletterItemAdmin(admin.ModelAdmin):
     form = NewsletterItemAdminForm
-    list_display = ['content_object', 'ordering']
+    list_display = ['content_type', 'content_object', 'ordering']
     list_editable = ['ordering']
     fieldsets = (
         (_('Article'), {'fields': ('object_id', 'content_type', 'ordering')}),
